@@ -1,4 +1,6 @@
-import sys
+import os, sys
+
+PROJECT_ROOT = os.path.abspath(os.path.dirname(__file__))
 
 DEBUG=True
 TEMPLATE_DEBUG=DEBUG
@@ -8,7 +10,6 @@ TEMPLATE_LOADERS = (
     'django.template.loaders.app_directories.load_template_source',
 )
 
-
 PROJECT_APPS = (
     'django.contrib.sessions', # just to enshure that dotted apps test works
     'django_jenkins',
@@ -24,8 +25,13 @@ DATABASE_ENGINE = 'sqlite3'
 JENKINS_TASKS = (
     'django_jenkins.tasks.with_coverage',
     'django_jenkins.tasks.django_tests',
+    'django_jenkins.tasks.run_pep8',
+    'django_jenkins.tasks.run_pyflakes',
+    'django_jenkins.tasks.run_jslint',
 )
 
+JSLINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/js/test.js')]
+
 # python > 2.4
 if sys.version_info[1] > 4:
     JENKINS_TASKS += ('django_jenkins.tasks.run_pylint',
